//
// C++ Implementation: kmfmainwindow
//
// Description:
//
//
// Author: Christian Hubinger <chubinger@irrsinnig.org>, (C) 2003
//
// Copyright: See COPYING file that comes with this distribution
//
//
/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/


#include "kmfmainwindow.h"
namespace KMF {
KMFMainWindow::KMFMainWindow( QWidget* parent, const char *name ) : KMyFirewallInterface(),  KParts::MainWindow( parent, name ) {}

KMFMainWindow::~KMFMainWindow() {}

}

#include "kmfmainwindow.moc"
